;; Generated package description from cond-star.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "cond-star" "1.0.0.20260228.134355" "Extended form of `cond' construct" '((emacs "24.3")) :commit "b7dedde7aa1d2765f09fbee54cf1cded29f40b86" :url "https://elpa.gnu.org/packages/cond-star.html" :maintainer '("Richard Stallman" . "rms@gnu.org"))
